@@ -127,8 +127,8 @@ very hard to parse.
 C<DH_GOLANG_INSTALL_EXTRA> (list of strings, whitespace-separated, default
 empty) enumerates files and directories which are additionally installed into
 the build directory. By default, only files with the following extension are
-installed: .go, .c, .cc, .h, .hh, .proto, .s. Starting with dh-golang 1.31,
-testdata directory contents are installed by default.
+installed: .go, .c, .cc, .cpp, .h, .hh, hpp, .proto, .s. Starting with dh-golang
+1.31, testdata directory contents are installed by default.
 
 Example (in C<debian/rules>):
 
@@ -138,8 +138,8 @@ Example (in C<debian/rules>):
 
 C<DH_GOLANG_INSTALL_ALL> (bool, default false) controls whether all files are
 installed into the build directory. By default, only files with the following
-extension are installed: .go, .c, .cc, .h, .hh, .proto, .s. Starting with
-dh-golang 1.31, testdata directory contents are installed by default.
+extension are installed: .go, .c, .cc, .cpp, .h, .hh, .hpp, .proto, .s. Starting
+with dh-golang 1.31, testdata directory contents are installed by default.
 
 Example (in C<debian/rules>):
 
@@ -243,7 +243,7 @@ use strict;
 use base 'Debian::Debhelper::Buildsystem';
 use Debian::Debhelper::Dh_Lib;
 use Dpkg::Control::Info;
-use File::Copy; # in core since 5.002
+use File::Copy "cp"; # in core since 5.002
 use File::Path qw(make_path); # in core since 5.001
 use File::Find; # in core since 5
 use File::Spec; # in core since 5.00405
@@ -340,8 +340,10 @@ sub configure {
         '.go' => 1,
         '.c' => 1,
         '.cc' => 1,
+        '.cpp' => 1,
         '.h' => 1,
         '.hh' => 1,
+        '.hpp' => 1,
         '.proto' => 1,
         '.s' => 1,
     );
@@ -411,7 +413,7 @@ sub configure {
 
         make_path(dirname($dest));
         verbose_print("Copy $source -> $dest");
-        copy($source, $dest) or error("Could not copy $source to $dest: $!");
+        cp($source, $dest) or error("Could not copy $source to $dest: $!");
     }
 
     ############################################################################
@@ -459,7 +461,8 @@ sub build {
         $this->doit_in_builddir("go", "generate", "-v", @_, get_targets());
     }
     unshift @_, ('-p', $this->get_parallel());
-    my $trimpath = "\"-trimpath=" . $ENV{GOPATH} . "/src\"";
+    # Go 1.10 changed flag behaviour, -{gc,asm}flags=all= only works for Go >= 1.10.
+    my $trimpath = "all=\"-trimpath=" . $ENV{GOPATH} . "/src\"";
     $this->doit_in_builddir("go", "install", "-gcflags=$trimpath", "-asmflags=$trimpath", "-v", @_, get_targets());
 }
 
@@ -549,7 +552,7 @@ sub install {
                 }
 
                 verbose_print("Copy $source -> $dest");
-                copy($source, $dest) or error("Could not copy $source to $dest: $!");
+                cp($source, $dest) or error("Could not copy $source to $dest: $!");
 
                 },
             no_chdir => 1,
